@@ -34,7 +34,7 @@ open Linux_kernels
 module G = Guestfs
 
 (* The conversion function. *)
-let convert (g : G.guestfs) source inspect keep_serial_console _ =
+let convert (g : G.guestfs) source inspect i_firmware _ keep_serial_console _ =
   (*----------------------------------------------------------------------*)
   (* Inspect the guest first.  We already did some basic inspection in
    * the common v2v.ml code, but that has to deal with generic guests
@@ -120,12 +120,13 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
   Array.iter g#rm_f (g#glob_expand "/var/lib/rpm/__db.00?");
 
   (* Detect the installed bootloader. *)
-  let bootloader = Linux_bootloaders.detect_bootloader g inspect in
+  let bootloader =
+    Linux_bootloaders.detect_bootloader g inspect.i_root i_firmware in
   Linux.augeas_reload g;
 
   (* Detect which kernels are installed and offered by the bootloader. *)
   let bootloader_kernels =
-    Linux_kernels.detect_kernels g inspect family bootloader in
+    Linux_kernels.detect_kernels g inspect.i_root bootloader inspect.i_apps in
 
   (*----------------------------------------------------------------------*)
   (* Conversion step. *)
@@ -152,8 +153,6 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
       bootloader#remove_console ();
     );
 
-    let acpi = supports_acpi () in
-
     let block_type =
       if kernel.ki_supports_virtio_blk then Virtio_blk else IDE in
     let net_type =
@@ -202,11 +201,12 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
 
     (* RHEL >= 9.0 on x86_64 requires the processor to support the "x86-64-v2"
      * microarchitecture level, which the default QEMU VCPU model does not
-     * satisfy.  Refer to RHBZ#2076013.
+     * satisfy.  Refer to RHBZ#2076013 RHBZ#2166619.
      *)
-    let default_cpu_suffices = inspect.i_distro <> "rhel" ||
-                               inspect.i_arch <> "x86_64" ||
-                               inspect.i_major_version < 9 in
+    let arch_min_version =
+      if family <> `RHEL_family || inspect.i_arch <> "x86_64" ||
+         inspect.i_major_version < 9
+      then 0 else 2 in
 
     (* Return guest capabilities from the convert () function. *)
     let guestcaps = {
@@ -218,9 +218,9 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
       gcaps_virtio_socket = kernel.ki_supports_virtio_socket;
       gcaps_machine = machine;
       gcaps_arch = Utils.kvm_arch inspect.i_arch;
-      gcaps_acpi = acpi;
+      gcaps_arch_min_version = arch_min_version;
       gcaps_virtio_1_0 = virtio_1_0;
-      gcaps_default_cpu = default_cpu_suffices;
+      gcaps_rtc_utc = true; (* almost all Linux expect RTC to be UTC *)
     } in
 
     guestcaps
@@ -239,7 +239,7 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
           else
             None
       ) inspect.i_apps in
-    Linux.remove g inspect xenmods;
+    Linux.remove g inspect.i_root xenmods;
 
     (* Undo related nastiness if kmod-xenpv was installed. *)
     if xenmods <> [] then (
@@ -254,7 +254,7 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
 
       (* Check it's not owned by an installed application. *)
       let dirs = List.filter (
-        fun d -> not (Linux.is_file_owned g inspect d)
+        fun d -> not (Linux.is_file_owned g inspect.i_root d)
       ) dirs in
 
       (* Remove any unowned xenpv directories. *)
@@ -312,7 +312,7 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
         fun { G.app2_name = name } -> name = package_name
       ) inspect.i_apps in
     if has_guest_additions then
-      Linux.remove g inspect [package_name];
+      Linux.remove g inspect.i_root [package_name];
 
     (* Guest Additions might have been installed from a tarball.  The
      * above code won't detect this case.  Look for the uninstall tool
@@ -458,7 +458,7 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
     );
 
     let remove = !remove in
-    Linux.remove g inspect remove;
+    Linux.remove g inspect.i_root remove;
 
     (* VMware Tools may have been installed from a tarball, so the
      * above code won't remove it.  Look for the uninstall tool and run
@@ -505,7 +505,7 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
     let pkgs = List.map (fun { G.app2_name = name } -> name) pkgs in
 
     if pkgs <> [] then (
-      Linux.remove g inspect pkgs;
+      Linux.remove g inspect.i_root pkgs;
 
       (* Installing these guest utilities automatically unconfigures
        * ttys in /etc/inittab if the system uses it. We need to put
@@ -970,13 +970,6 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
 
     g#aug_save ()
 
-  and supports_acpi () =
-    (* ACPI known to cause RHEL 3 to fail. *)
-    if family = `RHEL_family && inspect.i_major_version == 3 then
-      false
-    else
-      true
-
   and configure_display_driver () =
     let video_driver = "modesetting" in
 
@@ -1076,8 +1069,12 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
     (* Update 'alias scsi_hostadapter ...' *)
     let paths = augeas_modprobe ". =~ regexp('scsi_hostadapter.*')" in
     (match block_type with
-    | Virtio_blk ->
-      let block_module = "virtio_blk" in
+    | Virtio_blk | Virtio_SCSI ->
+      let block_module =
+        match block_type with
+        | Virtio_blk -> "virtio_blk"
+        | Virtio_SCSI -> "virtio_scsi"
+        | IDE -> assert false in
 
       if paths <> [] then (
         (* There's only 1 scsi controller in the converted guest.
@@ -1150,6 +1147,7 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
     let block_prefix_after_conversion =
       match block_type with
       | Virtio_blk -> "vd"
+      | Virtio_SCSI -> "sd"
       | IDE -> ide_block_prefix in
 
     let map =
@@ -1317,8 +1315,8 @@ let convert (g : G.guestfs) source inspect keep_serial_console _ =
        The following code tries to make an uefi fallback path for
        a uefi linux vm.
     *)
-    (match inspect.i_firmware with
-    | I_BIOS -> ()
+    (match i_firmware with
+    | Firmware.I_BIOS -> ()
     | I_UEFI _ ->
       (* Standard uefi fallback path *)
       let uefi_fallback_path = "/boot/efi/EFI/BOOT/" in
