@@ -38,10 +38,24 @@ module G = Guestfs
  * time the Windows VM is booted on KVM.
  *)
 
-let convert (g : G.guestfs) _ inspect _ static_ips =
+let convert (g : G.guestfs) _ inspect i_firmware block_driver _ static_ips =
   (*----------------------------------------------------------------------*)
   (* Inspect the Windows guest. *)
 
+  (* Locate virtio-win ISO or directory using the [VIRTIO_WIN]
+   * environment variable.
+   *)
+  let virtio_win =
+    Inject_virtio_win.from_environment g inspect.i_root Config.datadir in
+  (match block_driver with
+   | Virtio_blk -> () (* the default, no need to do anything *)
+   | Virtio_SCSI ->
+      let drivers = Inject_virtio_win.get_block_driver_priority virtio_win in
+      let drivers = "vioscsi" :: drivers in
+      Inject_virtio_win.set_block_driver_priority virtio_win drivers
+   | IDE -> assert false (* not possible - but maybe ...? *)
+  );
+
   (* If the Windows guest appears to be using group policy.
    *
    * Since this was written, it has been noted that it may be possible
@@ -89,6 +103,42 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
   (* If the Windows guest has AV installed. *)
   let has_antivirus = Windows.detect_antivirus inspect in
 
+  (* Does the guest expect the RTC to be set to UTC or localtime?
+   * See https://wiki.archlinux.org/title/System_time#UTC_in_Microsoft_Windows
+   * Note this might be a QWORD on 64 bit Windows instances.
+   *)
+  let rtc_utc =
+    Registry.with_hive_readonly g inspect.i_windows_system_hive
+      (fun reg ->
+       try
+         let key_path = [ "Control"; "TimeZoneInformation" ] in
+         let path = inspect.i_windows_current_control_set :: key_path in
+         let node =
+           match Registry.get_node reg path with
+           | None -> raise Not_found
+           | Some node -> node in
+         let valueh = g#hivex_node_get_value node "RealTimeIsUniversal" in
+         if valueh = 0L then raise Not_found;
+         let t = g#hivex_value_type valueh in
+         let data = g#hivex_value_value valueh in
+         let is_utc =
+           match t with
+           | 0_L (* REG_NONE *) -> false (* localtime *)
+           | 4_L (* REG_DWORD *) -> data = "\001\000\000\000"
+           | 11_L (* REG_QWORD *) -> data = "\001\000\000\000\000\000\000\000"
+           | _ (* who knows ... *) ->
+             warning (f_"unknown CurrentControlSet\\Control\\\
+                         TimeZoneInformation key RealTimeIsUniversal \
+                         type 0x%Lx, assuming RTC set to UTC") t;
+             true in
+         is_utc
+       with Not_found ->
+         (* If the key is not found then by default we assume
+          * that Windows is expecting the RTC to be set to localtime.
+          *)
+         false
+      ) in
+
   (* Open the software hive (readonly) and find the Xen PV uninstaller,
    * if it exists.
    *)
@@ -214,12 +264,7 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
     configure_firstboot ();
 
     (* Open the system hive for writes and update it. *)
-    let block_driver,
-        net_driver,
-        virtio_rng_supported,
-        virtio_ballon_supported,
-        isa_pvpanic_supported,
-        virtio_socket_supported =
+    let { Inject_virtio_win.block_driver; net_driver} as virtio_win_installed =
       Registry.with_hive_write g inspect.i_windows_system_hive
                                update_system_hive in
 
@@ -251,69 +296,47 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
                     disabling AV before doing the conversion.");
     );
 
-    let machine, virtio_1_0 =
-      match inspect.i_arch with
-      | ("i386"|"x86_64") ->
-        (try
-           (* Fall back to the decision that's based on the year that the OS
-            * was released in under three circumstances:
-            * - the user specified the location of the Windows virtio drivers
-            *   through an environment variable, or
-            * - "Libosinfo_utils.get_os_by_short_id" fails to look up the OS,
-            *   or
-            * - "Libosinfo_utils.best_driver" cannot find any matching driver.
-            * In each of these cases, a "Not_found" exception is raised.  This
-            * behavior exactly mirrors that of "Windows_virtio.copy_drivers".
-            *)
-           if Windows_virtio.virtio_win_from_env then
-             raise Not_found;
-           let os = Libosinfo_utils.get_os_by_short_id inspect.i_osinfo in
-           let devices = os#get_devices ()
-           and drivers = os#get_device_drivers () in
-           let best_drv_devs =
-             (Libosinfo_utils.best_driver drivers inspect.i_arch).devices in
-           debug "libosinfo internal devices for OS \"%s\":\n%s"
-             inspect.i_osinfo
-             (Libosinfo_utils.string_of_osinfo_device_list devices);
-           debug "libosinfo \"best driver\" devices for OS \"%s\":\n%s"
-             inspect.i_osinfo
-             (Libosinfo_utils.string_of_osinfo_device_list best_drv_devs);
-           let { Libosinfo_utils.q35; vio10 } =
-             Libosinfo_utils.os_support_of_osinfo_device_list
-               (devices @ best_drv_devs) in
-           (if q35 then Q35 else I440FX), vio10
-         with
-         | Not_found ->
-           (* Pivot on the year 2007.  Any Windows version from earlier than
-            * 2007 should use i440fx, anything 2007 or newer should use q35.
-            * Luckily this coincides almost exactly with the release of NT 6.
-            *)
-           (if inspect.i_major_version < 6 then I440FX else Q35), true
-        )
-      | _ -> Virt, true
-    in
-
     (* Return guest capabilities from the convert () function. *)
     let guestcaps = {
-      gcaps_block_bus = block_driver;
-      gcaps_net_bus = net_driver;
-      gcaps_virtio_rng = virtio_rng_supported;
-      gcaps_virtio_balloon = virtio_ballon_supported;
-      gcaps_isa_pvpanic = isa_pvpanic_supported;
-      gcaps_virtio_socket = virtio_socket_supported;
-      gcaps_machine = machine;
+      gcaps_block_bus = of_virtio_win_block_type block_driver;
+      gcaps_net_bus = of_virtio_win_net_type net_driver;
+      gcaps_virtio_rng = virtio_win_installed.Inject_virtio_win.virtio_rng;
+      gcaps_virtio_balloon =
+        virtio_win_installed.Inject_virtio_win.virtio_balloon;
+      gcaps_isa_pvpanic = virtio_win_installed.Inject_virtio_win.isa_pvpanic;
+      gcaps_virtio_socket =
+        virtio_win_installed.Inject_virtio_win.virtio_socket;
+      gcaps_machine = of_virtio_win_machine_type
+                        virtio_win_installed.Inject_virtio_win.machine;
       gcaps_arch = Utils.kvm_arch inspect.i_arch;
-      gcaps_acpi = true;
-      gcaps_virtio_1_0 = virtio_1_0;
-      gcaps_default_cpu = true;
+      gcaps_arch_min_version = 0;
+      gcaps_virtio_1_0 = virtio_win_installed.Inject_virtio_win.virtio_1_0;
+      gcaps_rtc_utc = rtc_utc;
     } in
 
     guestcaps
 
+  and of_virtio_win_block_type = function
+    | Inject_virtio_win.Virtio_blk -> Virtio_blk
+    | Virtio_SCSI -> Virtio_SCSI
+    | IDE -> IDE
+
+  and of_virtio_win_net_type = function
+    | Inject_virtio_win.Virtio_net -> Virtio_net
+    | E1000 -> E1000
+    | RTL8139 -> RTL8139
+
+  and of_virtio_win_machine_type = function
+    | Inject_virtio_win.I440FX -> I440FX
+    | Q35 -> Q35
+    | Virt -> Virt
+
   and configure_firstboot () =
-    (* Note that pnp_wait.exe must be the first firstboot script as it
-     * suppresses PnP for all following scripts.
+    (* Run the firstboot script with pnputil.exe before the one with
+     * pnp_wait.exe as the latter suppresses PnP for all following scripts.
      *)
+    configure_pnputil_install ();
+
     let tool_path = virt_tools_data_dir () // "pnp_wait.exe" in
     if Sys.file_exists tool_path then
       configure_wait_pnp tool_path
@@ -329,10 +352,7 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
       configure_vmdp tool_path;
 
     (* Install QEMU Guest Agent unconditionally and warn if missing *)
-    let qemu_ga_files = Windows_virtio.copy_qemu_ga g inspect in
-    if qemu_ga_files <> [] then
-      configure_qemu_ga qemu_ga_files
-    else
+    if not (Inject_virtio_win.inject_qemu_ga virtio_win) then
       warning (f_"QEMU Guest Agent MSI not found on tools ISO/directory. You \
                   may want to install the guest agent manually after \
                   conversion.");
@@ -364,6 +384,17 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
                       strkey name value
     | None -> sprintf "reg delete \"%s\" /v %s /f" strkey name
 
+  and configure_pnputil_install () =
+    let fb_script = "@echo off\n\
+                     \n\
+                     echo Wait for VirtIO drivers to be installed\n\
+                     %systemroot%\\Sysnative\\PnPutil -i -a \
+                     %systemroot%\\Drivers\\Virtio\\*.inf" in
+
+    (* Set priority higher than that of "v2vnetcf.ps1" firstboot script. *)
+    Firstboot.add_firstboot_script g inspect.i_root ~prio:2000
+      "pnputil install drivers" fb_script;
+
   and configure_wait_pnp tool_path =
     (* Prevent destructive interactions of firstboot with PnP. *)
 
@@ -406,7 +437,7 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
                       "@echo off\n\
                        \n\
                        echo Wait for PnP to complete\n\
-                       \"%s\" >\"%%~dpn0.log\" 2>&1\n\
+                       \"%s\"\n\
                        %s"
                       (String.replace_char pnp_wait_path '/' '\\')
                       reg_restore_str in
@@ -441,42 +472,6 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
     Firstboot.add_firstboot_script g inspect.i_root
       "finish vmdp setup" fb_recover_script
 
- and configure_qemu_ga files =
-   List.iter (
-     fun msi_path ->
-       (* Windows is a trashfire.
-        * https://stackoverflow.com/a/18730884
-        * https://bugzilla.redhat.com/show_bug.cgi?id=1895323
-        *)
-       let psh_script = ref [] in
-       let add = List.push_back psh_script in
-
-       add "# Uncomment this line for lots of debug output.";
-       add "# Set-PSDebug -Trace 2";
-       add "";
-       add "Write-Host Removing any previously scheduled qemu-ga installation";
-       add "schtasks.exe /Delete /TN Firstboot-qemu-ga /F";
-       add "";
-       add (sprintf
-              "Write-Host Scheduling delayed installation of qemu-ga from %s"
-              msi_path);
-       add "$d = (get-date).AddSeconds(120)";
-       add "$dtfinfo = [System.Globalization.DateTimeFormatInfo]::CurrentInfo";
-       add "$sdp = $dtfinfo.ShortDatePattern";
-       add "$sdp = $sdp -replace 'y+', 'yyyy'";
-       add "$sdp = $sdp -replace 'M+', 'MM'";
-       add "$sdp = $sdp -replace 'd+', 'dd'";
-       add "schtasks.exe /Create /SC ONCE `";
-       add "  /ST $d.ToString('HH:mm') /SD $d.ToString($sdp) `";
-       add "  /RU SYSTEM /TN Firstboot-qemu-ga `";
-       add (sprintf "  /TR \"C:\\%s /forcerestart /qn /l+*vx C:\\%s.log\""
-              msi_path msi_path);
-
-      Windows.install_firstboot_powershell g inspect
-        (sprintf "install-%s.ps1" msi_path) !psh_script;
-    ) files
-
-
   and unconfigure_xenpv () =
     match xenpv_uninst with
     | None -> () (* nothing to be uninstalled *)
@@ -533,7 +528,7 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
     disable_xenpv_win_drivers reg;
     disable_prl_drivers reg;
     disable_autoreboot reg;
-    Windows_virtio.install_drivers reg inspect
+    Inject_virtio_win.inject_virtio_win_drivers virtio_win reg
 
   and disable_xenpv_win_drivers reg =
     (* Disable xenpv-win service (RHBZ#809273). *)
@@ -744,8 +739,8 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
        *
        * Place it first among the firstboot scripts (RHBZ#1788823).
        *)
-      Windows.install_firstboot_powershell g inspect ~prio:2500 psh_filename
-        !psh
+      Firstboot.add_firstboot_powershell g inspect.i_root ~prio:2500
+        psh_filename !psh
     ) (* static_ips <> [] *)
 
   and fix_ntfs_heads () =
@@ -858,8 +853,8 @@ let convert (g : G.guestfs) _ inspect _ static_ips =
         )
     in
 
-    match inspect.i_firmware with
-    | I_BIOS -> ()
+    match i_firmware with
+    | Firmware.I_BIOS -> ()
     | I_UEFI esp_list ->
       let esp_temp_path = g#mkdtemp "/Windows/Temp/ESP_XXXXXX" in
       let uefi_arch = get_uefi_arch_suffix inspect.i_arch in
