@@ -44,7 +44,8 @@ let get_drive_slot str offset =
   let name = String.sub str offset (String.length str - offset) in
   try Some (drive_index name)
   with Invalid_argument _ ->
-       warning (f_"could not parse device name ‘%s’ from the source libvirt XML") str;
+       warning (f_"could not parse device name ‘%s’ \
+                   from the source libvirt XML") str;
        None
 
 let parse_libvirt_xml ?conn xml =
@@ -70,7 +71,8 @@ let parse_libvirt_xml ?conn xml =
   let hypervisor =
     match xpath_string "/domain/@type" with
     | None | Some "" ->
-       error (f_"in the libvirt XML metadata, <domain type='...'> is missing or empty")
+       error (f_"in the libvirt XML metadata, <domain type='...'> \
+                 is missing or empty")
     | Some s -> source_hypervisor_of_string s in
   let name =
     match xpath_string "/domain/name/text()" with
@@ -82,7 +84,7 @@ let parse_libvirt_xml ?conn xml =
     | None | Some "" -> None
     | Some _ as s -> s in
   let memory =
-    Option.default (1024L *^ 1024L) (xpath_int64 "/domain/memory/text()") in
+    Option.value ~default:(1024L *^ 1024L) (xpath_int64 "/domain/memory/text()") in
   let memory = memory *^ 1024L in
 
   let cpu_vendor = xpath_string "/domain/cpu/vendor/text()" in
@@ -101,9 +103,9 @@ let parse_libvirt_xml ?conn xml =
     | Some vcpu, _,    _,    _    -> vcpu
     | None,      None, None, None -> 1
     | None,      _,    _,    _    ->
-       let sockets = Option.default 1 cpu_sockets
-       and cores = Option.default 1 cpu_cores
-       and threads = Option.default 1 cpu_threads in
+       let sockets = Option.value ~default:1 cpu_sockets
+       and cores = Option.value ~default:1 cpu_cores
+       and threads = Option.value ~default:1 cpu_threads in
        sockets * cores * threads in
 
   let cpu_topology =
@@ -155,7 +157,8 @@ let parse_libvirt_xml ?conn xml =
           | Some "none" ->
             LNone
           | Some t ->
-            warning (f_"<listen type='%s'> in the input libvirt XML was ignored") t;
+            warning (f_"<listen type='%s'> in the input libvirt XML \
+                        was ignored") t;
             LNoListen
         ) in
       let port =
@@ -176,10 +179,13 @@ let parse_libvirt_xml ?conn xml =
                s_keymap = keymap; s_password = password; s_listen = listen;
                s_port = port }
       | Some ("sdl"|"desktop" as t) ->
-        warning (f_"virt-v2v does not support local displays, so <graphics type='%s'> in the input libvirt XML was ignored") t;
+        warning (f_"virt-v2v does not support local displays, so \
+                    <graphics type='%s'> in the input libvirt XML was ignored")
+          t;
         None
       | Some t ->
-        warning (f_"display <graphics type='%s'> in the input libvirt XML was ignored") t;
+        warning (f_"display <graphics type='%s'> in the input \
+                    libvirt XML was ignored") t;
         None
     ) in
 
@@ -284,7 +290,7 @@ let parse_libvirt_xml ?conn xml =
            (* This is for testing curl, eg for testing VMware conversions
             * without needing VMware around.
             *)
-           let path = Option.default "" (xpath_string "source/@name") in
+           let path = Option.value ~default:"" (xpath_string "source/@name") in
            let url =
              let port =
                match driver, port with
@@ -297,7 +303,8 @@ let parse_libvirt_xml ?conn xml =
              sprintf "%s://%s%s%s" driver host port (uri_quote path) in
            add_disk format controller (HTTP url)
         | Some protocol, _, _ ->
-           warning (f_"<disk type='network'> with <source protocol='%s'> was ignored")
+           warning (f_"<disk type='network'> with <source protocol='%s'> \
+                       was ignored")
                    protocol
         )
       | Some "volume" ->
@@ -323,7 +330,8 @@ let parse_libvirt_xml ?conn xml =
              | None -> ()
             );
           | Some vol_type ->
-            warning (f_"<disk type='volume'> with <volume type='%s'> was ignored") vol_type
+            warning (f_"<disk type='volume'> with <volume type='%s'> \
+                        was ignored") vol_type
           )
         )
       | Some disk_type ->
@@ -364,13 +372,15 @@ let parse_libvirt_xml ?conn xml =
            let name = String.sub dev 2 (String.length dev - 2) in
            (try Some (int_of_string name)
             with Failure _ ->
-              warning (f_"could not parse device name ‘%s’ from the source libvirt XML") dev;
+              warning (f_"could not parse device name ‘%s’ \
+                          from the source libvirt XML") dev;
               None
            )
         | Some dev ->
            let rec loop = function
              | [] ->
-                warning (f_"<target dev='%s'> was ignored because the device name could not be recognized") dev;
+                warning (f_"<target dev='%s'> was ignored because \
+                            the device name could not be recognized") dev;
                 None
              | prefix :: rest ->
                 if String.is_prefix dev prefix then (
