@@ -121,11 +121,11 @@ NICs:
 "
     s.s_name
     (string_of_source_hypervisor s.s_hypervisor)
-    (Option.default "" s.s_genid)
+    (Option.value ~default:"" s.s_genid)
     s.s_memory
     s.s_vcpu
-    (Option.default "" s.s_cpu_vendor)
-    (Option.default "" s.s_cpu_model)
+    (Option.value ~default:"" s.s_cpu_vendor)
+    (Option.value ~default:"" s.s_cpu_model)
     (match s.s_cpu_topology with
     | None -> ""
     | Some topology -> string_of_source_cpu_topology topology)
@@ -248,7 +248,8 @@ and string_of_source_display { s_display_type = typ;
     | LAddress a -> sprintf " listening on address %s" a
     | LNetwork n -> sprintf " listening on network %s" n
     | LSocket (Some s) -> sprintf " listening on Unix domain socket %s" s
-    | LSocket None -> sprintf " listening on automatically created Unix domain socket"
+    | LSocket None ->
+       sprintf " listening on automatically created Unix domain socket"
     | LNone -> " listening on private fd"
     )
 
@@ -298,15 +299,11 @@ type inspect = {
   i_mountpoints : (string * string) list;
   i_apps : Guestfs.application2 list;
   i_apps_map : Guestfs.application2 list StringMap.t;
-  i_firmware : i_firmware;
   i_windows_systemroot : string;
   i_windows_software_hive : string;
   i_windows_system_hive : string;
   i_windows_current_control_set : string;
 }
-and i_firmware =
-  | I_BIOS
-  | I_UEFI of string list
 
 let string_of_inspect inspect =
   sprintf "\
@@ -321,7 +318,6 @@ i_package_format = %s
 i_package_management = %s
 i_product_name = %s
 i_product_variant = %s
-i_firmware = %s
 i_windows_systemroot = %s
 i_windows_software_hive = %s
 i_windows_system_hive = %s
@@ -337,9 +333,6 @@ i_windows_current_control_set = %s
   inspect.i_package_management
   inspect.i_product_name
   inspect.i_product_variant
-  (match inspect.i_firmware with
-   | I_BIOS -> "BIOS"
-   | I_UEFI devices -> sprintf "UEFI [%s]" (String.concat ", " devices))
   inspect.i_windows_systemroot
   inspect.i_windows_software_hive
   inspect.i_windows_system_hive
@@ -404,16 +397,17 @@ type guestcaps = {
   gcaps_virtio_socket : bool;
   gcaps_machine : guestcaps_machine;
   gcaps_arch : string;
-  gcaps_acpi : bool;
+  gcaps_arch_min_version : int;
   gcaps_virtio_1_0 : bool;
-  gcaps_default_cpu : bool;
+  gcaps_rtc_utc : bool;
 }
-and guestcaps_block_type = Virtio_blk | IDE
+and guestcaps_block_type = Virtio_blk | Virtio_SCSI | IDE
 and guestcaps_net_type = Virtio_net | E1000 | RTL8139
 and guestcaps_machine = I440FX | Q35 | Virt
 
 let string_of_block_type = function
   | Virtio_blk -> "virtio-blk"
+  | Virtio_SCSI -> "virtio-scsi"
   | IDE -> "ide"
 let string_of_net_type = function
   | Virtio_net -> "virtio-net"
@@ -434,9 +428,9 @@ let string_of_guestcaps gcaps =
            gcaps_virtio_socket = %b\n\
            gcaps_machine = %s\n\
            gcaps_arch = %s\n\
-           gcaps_acpi = %b\n\
+           gcaps_arch_min_version = %d\n\
            gcaps_virtio_1_0 = %b\n\
-           gcaps_default_cpu = %b\n\
+           gcaps_rtc_utc = %b\n\
           "
   (string_of_block_type gcaps.gcaps_block_bus)
   (string_of_net_type gcaps.gcaps_net_bus)
@@ -446,9 +440,9 @@ let string_of_guestcaps gcaps =
   gcaps.gcaps_virtio_socket
   (string_of_machine gcaps.gcaps_machine)
   gcaps.gcaps_arch
-  gcaps.gcaps_acpi
+  gcaps.gcaps_arch_min_version
   gcaps.gcaps_virtio_1_0
-  gcaps.gcaps_default_cpu
+  gcaps.gcaps_rtc_utc
 
 type target_buses = {
   target_virtio_blk_bus : target_bus_slot array;
