@@ -189,18 +189,11 @@ type inspect = {
     (** This is a map from the app name to the application object.
         Since RPM allows multiple packages with the same name to be
         installed, the value is a list. *)
-  i_firmware : i_firmware;
-    (** The list of EFI system partitions for the guest with UEFI,
-        otherwise the BIOS identifier. *)
   i_windows_systemroot : string;
   i_windows_software_hive : string;
   i_windows_system_hive : string;
   i_windows_current_control_set : string;
 }
-and i_firmware =
-  | I_BIOS
-  | I_UEFI of string list
-(** Inspection information. *)
 
 val string_of_inspect : inspect -> string
 
@@ -269,30 +262,30 @@ type guestcaps = {
   gcaps_virtio_socket : bool;   (** Guest supports virtio socket. *)
   gcaps_machine : guestcaps_machine; (** Machine model. *)
   gcaps_arch : string;          (** Architecture that KVM must emulate. *)
-  gcaps_acpi : bool;            (** True if guest supports acpi. *)
+
+  gcaps_arch_min_version : int;
+  (** Some guest OSes require not just a specific architecture, but a
+      minimum version.  Notably RHEL >= 9 requires at least x86_64-v2.
+
+      If the guest is capable of running on QEMU's default VCPU model
+      for the architecture ([-cpu qemu64]) then this is set to [0].
+
+      Note this capability is not actually used by any current output
+      mode.  It is retained in case we might use it in future, but we
+      might remove it if it is not used. *)
 
   gcaps_virtio_1_0 : bool;
   (** The guest supports the virtio devices that it does at the virtio-1.0
       protocol level. *)
 
-  gcaps_default_cpu : bool;
-  (** True iff the guest OS is capable of running on QEMU's default VCPU model
-      (eg. "-cpu qemu64" with the Q35 and I440FX machine types).
-
-      This capability only matters for the QEMU and libvirt output modules,
-      where, in case the capability is false *and* the source hypervisor does
-      not specify a VCPU model, we must manually present the guest OS with a
-      VCPU that looks as close as possible to a physical CPU.  (In that case, we
-      specify host-passthrough.)
-
-      The management applications targeted by the RHV and OpenStack output
-      modules have their own explicit VCPU defaults, overriding the QEMU default
-      model even in case the source hypervisor does not specify a VCPU model;
-      those modules ignore this capability therefore.  Refer to RHBZ#2076013. *)
+  gcaps_rtc_utc : bool;
+  (** Is the RTC set to UTC ([true]) or localtime ([false])?  For
+      Linux guests this is always true.  For Windows we find out
+      what the guest is expecting by looking at the registry. *)
 }
 (** Guest capabilities after conversion.  eg. Was virtio found or installed? *)
 
-and guestcaps_block_type = Virtio_blk | IDE
+and guestcaps_block_type = Virtio_blk | Virtio_SCSI | IDE
 and guestcaps_net_type = Virtio_net | E1000 | RTL8139
 and guestcaps_machine = I440FX | Q35 | Virt
 
