@@ -29,8 +29,13 @@ open Utils
 open Output
 open Create_kubevirt_yaml
 
+(* Valid output names for Kubevirt (RHBZ#2162332). *)
+let rfc1123_re =
+  PCRE.compile
+    "^[a-z0-9]([-a-z0-9]*[a-z0-9])?(\\.[a-z0-9]([-a-z0-9]*[a-z0-9])?)*$"
+
 module Kubevirt = struct
-  type poptions = output_allocation * string * string * string
+  type poptions = bool * output_allocation * string * string * string
 
   type t = unit
 
@@ -41,30 +46,51 @@ module Kubevirt = struct
       | None -> ""
 
   let query_output_options () =
-    printf (f_"No output options can be used in this mode.\n")
+    printf (f_"Output options that can be used with -o kubevirt:
+
+  -oo compressed      Compress the output file (used only with -of qcow2)
+")
+
 
   let parse_options options source =
-    if options.output_options <> [] then
-      error (f_"no -oo (output options) are allowed here");
+    let compressed = ref false in
+    List.iter (
+      function
+      | "compressed", "" -> compressed := true
+      | "compressed", v -> compressed := bool_of_string v
+      | k, _ ->
+         error (f_"-o kubevirt: unknown output option ‘-oo %s’") k
+    ) options.output_options;
+
     if options.output_password <> None then
-      error_option_cannot_be_used_in_output_mode "local" "-op";
+      error_option_cannot_be_used_in_output_mode "kubevirt" "-op";
 
     (* -os must be set to a directory. *)
     let output_storage =
       match options.output_storage with
       | None ->
-         error (f_"-o kubevirt: output directory was not specified, use '-os /dir'")
+         error (f_"-o kubevirt: output directory was not specified, \
+                   use '-os /dir'")
       | Some d when not (is_directory d) ->
-         error (f_"-os %s: output directory does not exist or is not a directory") d
+         error (f_"-os %s: output directory does not exist or \
+                   is not a directory") d
       | Some d -> d in
 
-    let output_name = Option.default source.s_name options.output_name in
+    let output_name = Option.value ~default:source.s_name options.output_name in
 
-    options.output_alloc, options.output_format, output_name, output_storage
+    if not (PCRE.matches rfc1123_re output_name) then
+      error (f_"-o kubevirt: the guest name must contain only lowercase \
+                alphanumeric characters, '-' or '.', and must start and \
+                end with an alphanumeric character.  Rerun virt-v2v with \
+                the '-on name' option to rename it.");
+
+    !compressed, options.output_alloc, options.output_format,
+    output_name, output_storage
 
   let setup dir options source =
     let disks = get_disks dir in
-    let output_alloc, output_format, output_name, output_storage = options in
+    let compressed, output_alloc, output_format, output_name, output_storage =
+      options in
 
     List.iter (
       fun (i, size) ->
@@ -73,11 +99,12 @@ module Kubevirt = struct
 
         (* Create the actual output disk. *)
         let outdisk = disk_path output_storage output_name i in
-        output_to_local_file output_alloc output_format outdisk size socket
+        output_to_local_file ~compressed output_alloc output_format
+          outdisk size socket
     ) disks
 
   let finalize dir options () source inspect target_meta =
-    let output_alloc, output_format, output_name, output_storage = options in
+    let _, output_alloc, output_format, output_name, output_storage = options in
 
     let doc = create_kubevirt_yaml source inspect target_meta
                 (disk_path output_storage output_name)
