@@ -71,10 +71,11 @@ module QEMU = struct
       | None ->
          error (f_"-o qemu: output directory was not specified, use '-os /dir'")
       | Some d when not (is_directory d) ->
-         error (f_"-os %s: output directory does not exist or is not a directory") d
+         error (f_"-os %s: output directory does not exist or is \
+                   not a directory") d
       | Some d -> d in
 
-    let output_name = Option.default source.s_name options.output_name in
+    let output_name = Option.value ~default:source.s_name options.output_name in
 
     (compressed, qemu_boot, options.output_alloc, options.output_format,
      output_name, output_storage)
@@ -157,6 +158,8 @@ module QEMU = struct
         arg_list "-device" ["vmgenid"; sprintf "guid=%s" genid; "id=vmgenid0"]
     );
 
+    if not guestcaps.gcaps_rtc_utc then arg "-rtc" "base=localtime";
+
     arg_list "-machine" (machine_str ::
                            (if smm then ["smm=on"] else []) @
                            ["accel=kvm:tcg"]);
@@ -174,11 +177,7 @@ module QEMU = struct
 
     arg "-m" (Int64.to_string (source.s_memory /^ 1024L /^ 1024L));
 
-    (match source.s_cpu_model, guestcaps.gcaps_default_cpu with
-      | None, true -> ()
-      | None, false -> arg "-cpu" "host"
-      | Some model, _ -> arg "-cpu" model
-    );
+    arg "-cpu" (Option.value ~default:"host" source.s_cpu_model);
 
     if source.s_vcpu > 1 then (
       (match source.s_cpu_topology with
