@@ -34,8 +34,8 @@ open Types
 open Utils
 
 (* Matches --mac command line parameters. *)
-let mac_re = PCRE.compile ~anchored:true "([[:xdigit:]]{2}:[[:xdigit:]]{2}:[[:xdigit:]]{2}:[[:xdigit:]]{2}:[[:xdigit:]]{2}:[[:xdigit:]]{2}):(network|bridge|ip):(.*)"
-let mac_ip_re = PCRE.compile ~anchored:true "([[:xdigit:]]|:|\\.)+"
+let mac_re = PCRE.compile "^([[:xdigit:]]{2}:[[:xdigit:]]{2}:[[:xdigit:]]{2}:[[:xdigit:]]{2}:[[:xdigit:]]{2}:[[:xdigit:]]{2}):(network|bridge|ip):(.*)$"
+let mac_ip_re = PCRE.compile "^([[:xdigit:]]|:|\\.)+$"
 
 let rec main () =
   let set_string_option_once optname optref arg =
@@ -48,6 +48,7 @@ let rec main () =
 
   let bandwidth = ref None in
   let bandwidth_file = ref None in
+  let block_driver = ref None in
   let input_conn = ref None in
   let input_format = ref None in
   let input_password = ref None in
@@ -123,10 +124,11 @@ let rec main () =
      *)
     let rec error_unless_ip_addr what addr =
       if not (PCRE.matches mac_ip_re addr) then
-        error (f_"cannot parse --mac ip %s: doesn’t look like “%s” is an IP address") what addr
+        error (f_"cannot parse --mac ip %s: doesn’t look like “%s” \
+                  is an IP address") what addr
     in
     error_unless_ip_addr "ipaddr" if_ip_address;
-    Option.may (error_unless_ip_addr "gw") if_default_gateway;
+    Option.iter (error_unless_ip_addr "gw") if_default_gateway;
     List.iter (error_unless_ip_addr "nameserver") if_nameservers;
     let if_prefix_length =
       match if_prefix_length_str with
@@ -134,7 +136,8 @@ let rec main () =
       | Some len ->
          let len =
            try int_of_string len with
-           | Failure _ -> error (f_"cannot parse --mac ip prefix length field as an integer: %s") len in
+           | Failure _ -> error (f_"cannot parse --mac ip prefix length field \
+                                    as an integer: %s") len in
          if len < 0 || len > 128 then
            error (f_"--mac ip prefix length field is out of range");
          Some len in
@@ -228,6 +231,8 @@ let rec main () =
                                     s_"Set bandwidth dynamically from file";
     [ S 'b'; L"bridge" ], Getopt.String ("in:out", add_bridge),
       s_"Map bridge ‘in’ to ‘out’";
+    [ L"block-driver" ], Getopt.String ("driver", set_string_option_once "--block-driver" block_driver),
+                                    s_"Prefer 'virtio-blk' or 'virtio-scsi'";
     [ L"compressed" ], Getopt.Unit (fun () -> set_output_option_compat "compressed" ""),
       s_"Compress output file (-of qcow2 only)";
     [ S 'i' ],       Getopt.String ("disk|libvirt|libvirtxml|ova|vmx", set_input_mode),
@@ -329,7 +334,8 @@ A short summary of the options is given below.  For detailed help please
 read the man page virt-v2v(1).
 ")
       prog in
-  let opthandle = create_standard_options argspec ~anon_fun ~key_opts:true ~machine_readable:true usage_msg in
+  let opthandle = create_standard_options argspec ~anon_fun ~key_opts:true
+                    ~machine_readable:true usage_msg in
   Getopt.parse opthandle.getopt;
 
   (* Print the version, easier than asking users to tell us. *)
@@ -348,6 +354,12 @@ read the man page virt-v2v(1).
 
   (* Dereference the arguments. *)
   let args = List.rev !args in
+  let block_driver =
+    match !block_driver with
+    | None | Some "virtio-blk" -> Virtio_blk
+    | Some "virtio-scsi" -> Virtio_SCSI
+    | Some driver ->
+       error (f_"unknown block driver ‘--block-driver %s’") driver in
   let input_conn = !input_conn in
   let input_mode = !input_mode in
   let input_transport =
@@ -420,7 +432,8 @@ read the man page virt-v2v(1).
           let { Xml.uri_server = server; uri_scheme = scheme } =
             try Xml.parse_uri orig_uri
             with Invalid_argument msg ->
-              error (f_"could not parse '-ic %s'.  Original error message was: %s")
+              error (f_"could not parse '-ic %s'.  \
+                        Original error message was: %s")
                 orig_uri msg in
 
           match server, scheme, input_transport with
@@ -450,7 +463,9 @@ read the man page virt-v2v(1).
 
           (* Unknown remote scheme. *)
           | Some _, Some _, _ ->
-             warning (f_"no support for remote libvirt connections to '-ic %s'.  The conversion may fail when it tries to read the source disks.") orig_uri;
+             warning (f_"no support for remote libvirt connections to \
+                         '-ic %s'.  The conversion may fail when it tries \
+                         to read the source disks.") orig_uri;
              (module Input_libvirt.Libvirt_) in
 
   let input_options = {
@@ -493,7 +508,7 @@ read the man page virt-v2v(1).
   let output_options = {
     Output.output_alloc = output_alloc;
     output_conn = !output_conn;
-    output_format = Option.default "raw" !output_format;
+    output_format = Option.value ~default:"raw" !output_format;
     output_name = output_name;
     output_options = !output_options;
     output_password = !output_password;
@@ -518,7 +533,8 @@ read the man page virt-v2v(1).
 
   (* Get the conversion options. *)
   let conv_options = {
-    Convert.keep_serial_console = not remove_serial_console;
+    Convert.block_driver = block_driver;
+    keep_serial_console = not remove_serial_console;
     ks = opthandle.ks;
     network_map;
     root_choice;
@@ -627,8 +643,14 @@ and check_host_free_space () =
   debug "check_host_free_space: large_tmpdir=%s free_space=%Ld"
         large_tmpdir free_space;
   if free_space < 1_073_741_824L then
-    error (f_"insufficient free space in the conversion server temporary directory %s (%s).\n\nEither free up space in that directory, or set the LIBGUESTFS_CACHEDIR environment variable to point to another directory with more than 1GB of free space.\n\nSee also the virt-v2v(1) manual, section \"Minimum free space check in the host\".")
-          large_tmpdir (human_size free_space)
+    error (f_"insufficient free space in the conversion server \
+              temporary directory %s (%s).\n\nEither free up space \
+              in that directory, or set the LIBGUESTFS_CACHEDIR \
+              environment variable to point to another directory \
+              with more than 1GB of free space.\n\nSee also the \
+              virt-v2v(1) manual, section \
+              \"Minimum free space check in the host\".")
+      large_tmpdir (human_size free_space)
 
 and nbdcopy ?request_size output_alloc input_uri output_uri =
   (* XXX It's possible that some output modes know whether
